@@ -1,3 +1,3 @@
 from extra_views.formsets import FormSetView, ModelFormSetView, InlineFormSetView
 from extra_views.advanced import CreateWithInlinesView, UpdateWithInlinesView, InlineFormSet
-from extra_views.dates import CalendarMonthArchiveView
\ No newline at end of file
+from extra_views.dates import CalendarMonthView
